@@ -1,14 +1,5 @@
-#!/usr/bin/env python
 #This file is part of Tryton.  The COPYRIGHT file at the top level of
 #this repository contains the full copyright notices and license terms.
-
-import sys
-import os
-DIR = os.path.abspath(os.path.normpath(os.path.join(__file__,
-            '..', '..', '..', '..', '..', 'trytond')))
-if os.path.isdir(DIR):
-    sys.path.insert(0, os.path.dirname(DIR))
-
 import unittest
 from decimal import Decimal
 import datetime
@@ -20,14 +11,13 @@ from trytond.transaction import Transaction
 
 
 class StockForecastTestCase(unittest.TestCase):
-    '''
-    Test StockForecast module.
-    '''
+    'Test StockForecast module'
 
     def setUp(self):
         trytond.tests.test_tryton.install_module('stock_forecast')
         self.category = POOL.get('product.category')
         self.uom = POOL.get('product.uom')
+        self.template = POOL.get('product.template')
         self.product = POOL.get('product.product')
         self.location = POOL.get('stock.location')
         self.company = POOL.get('company.company')
@@ -37,21 +27,15 @@ class StockForecastTestCase(unittest.TestCase):
         self.move = POOL.get('stock.move')
 
     def test0005views(self):
-        '''
-        Test views.
-        '''
+        'Test views'
         test_view('stock_forecast')
 
     def test0006depends(self):
-        '''
-        Test depends.
-        '''
+        'Test depends'
         test_depends()
 
     def test0020distribute(self):
-        '''
-        Test distribute.
-        '''
+        'Test distribute'
         for values, result in (
                 ((1, 5), {0: 5}),
                 ((4, 8), {0: 2, 1: 2, 2: 2, 3: 2}),
@@ -62,27 +46,30 @@ class StockForecastTestCase(unittest.TestCase):
             self.assertEqual(self.line.distribute(*values), result)
 
     def test0030create_moves(self):
-        '''
-        Test create_moves.
-        '''
+        'Test create_moves'
         with Transaction().start(DB_NAME, USER, context=CONTEXT):
-            category = self.category.create({
-                    'name': 'Test create_moves',
-                    })
+            category, = self.category.create([{
+                        'name': 'Test create_moves',
+                        }])
             unit, = self.uom.search([('name', '=', 'Unit')])
-            product = self.product.create({
-                    'name': 'Test create_moves',
-                    'type': 'goods',
-                    'category': category.id,
-                    'cost_price_method': 'fixed',
-                    'default_uom': unit.id,
-                    'list_price': Decimal('1'),
-                    'cost_price': Decimal(0),
-                    })
+            template, = self.template.create([{
+                        'name': 'Test create_moves',
+                        'type': 'goods',
+                        'category': category.id,
+                        'cost_price_method': 'fixed',
+                        'default_uom': unit.id,
+                        'list_price': Decimal('1'),
+                        'cost_price': Decimal(0),
+                        }])
+            product, = self.product.create([{
+                        'template': template.id,
+                        }])
             customer, = self.location.search([('code', '=', 'CUS')])
             warehouse, = self.location.search([('code', '=', 'WH')])
             storage, = self.location.search([('code', '=', 'STO')])
-            company, = self.company.search([('name', '=', 'B2CK')])
+            company, = self.company.search([
+                    ('rec_name', '=', 'Dunder Mifflin'),
+                    ])
             self.user.write([self.user(USER)], {
                     'main_company': company.id,
                     'company': company.id,
@@ -90,22 +77,22 @@ class StockForecastTestCase(unittest.TestCase):
 
             today = datetime.date.today()
 
-            forecast = self.forecast.create({
-                    'warehouse': warehouse.id,
-                    'destination': customer.id,
-                    'from_date': today + relativedelta(months=1, day=1),
-                    'to_date': today + relativedelta(months=1, day=20),
-                    'company': company.id,
-                    'lines': [
-                        ('create', {
-                                'product': product.id,
-                                'quantity': 10,
-                                'uom': unit.id,
-                                'minimal_quantity': 2,
-                                },
-                            ),
-                        ],
-                    })
+            forecast, = self.forecast.create([{
+                        'warehouse': warehouse.id,
+                        'destination': customer.id,
+                        'from_date': today + relativedelta(months=1, day=1),
+                        'to_date': today + relativedelta(months=1, day=20),
+                        'company': company.id,
+                        'lines': [
+                            ('create', [{
+                                        'product': product.id,
+                                        'quantity': 10,
+                                        'uom': unit.id,
+                                        'minimal_quantity': 2,
+                                        }],
+                                ),
+                            ],
+                        }])
             self.forecast.confirm([forecast])
 
             self.forecast.create_moves([forecast])
@@ -118,17 +105,17 @@ class StockForecastTestCase(unittest.TestCase):
             line, = forecast.lines
             self.assertEqual(len(line.moves), 0)
 
-            self.move.create({
-                    'from_location': storage.id,
-                    'to_location': customer.id,
-                    'product': product.id,
-                    'uom': unit.id,
-                    'quantity': 2,
-                    'planned_date': today + relativedelta(months=1, day=5),
-                    'company': company.id,
-                    'currency': company.currency.id,
-                    'unit_price': Decimal('1'),
-                    })
+            self.move.create([{
+                        'from_location': storage.id,
+                        'to_location': customer.id,
+                        'product': product.id,
+                        'uom': unit.id,
+                        'quantity': 2,
+                        'planned_date': today + relativedelta(months=1, day=5),
+                        'company': company.id,
+                        'currency': company.currency.id,
+                        'unit_price': Decimal('1'),
+                        }])
             line, = forecast.lines
             self.assertEqual(line.quantity_executed, 2)
 
@@ -148,6 +135,3 @@ def suite():
     suite.addTests(unittest.TestLoader().loadTestsFromTestCase(
             StockForecastTestCase))
     return suite
-
-if __name__ == '__main__':
-    unittest.TextTestRunner(verbosity=2).run(suite())
